@@ -2,21 +2,27 @@ package Alien::GMP;
 
 use strict;
 use warnings;
-use parent 'Alien::Base';
-use Role::Tiny::With qw( with );
+use base 'Alien::Base';
 
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.14'; # VERSION
 # ABSTRACT: Alien package for the GNU Multiple Precision library.
 
-with 'Alien::Role::Alt';
-
 1;
-=encoding utf8
+
+__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Alien::GMP - Alien package for the GNU Multiple Precision library.
 
+=head1 VERSION
+
+version 1.14
+
 =head1 SYNOPSIS
 
 In your Build.PL:
@@ -90,13 +96,22 @@ L<GMP|https://gmplib.org/>
 
 =head1 AUTHOR
 
-Richard Simões C<< <rsimoes AT cpan DOT org> >>
+Original author: Richard Simões (RSIMOES)
 
-=head1 COPYRIGHT & LICENSE
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-Copyright © 2012 Richard Simões. This module is released under the terms of the
-L<GNU Lesser General Public License|http://gnu.org/licenses/lgpl.html> ("LGPL")
-v. 3.0 and may be modified and/or redistributed under the same or any compatible
-license. The GNU Multiple Precision library itself is copyrighted by the
-L<Free Software Foundation|http://www.fsf.org/> and is also distributed under
-terms of the LGPL v. 3.0.
+Contributors:
+
+Zakariyya Mughal (ZMUGHAL)
+
+William N. Braswell, Jr. (WBRASWELL)
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012-2018 by Richard Simões.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 3, June 2007
+
+=cut
